@@ -18,7 +18,7 @@ use Carp;
 
 requires 'submit', 'get_contacts_by_domain_name', 'delete_private_nameserver';
 
-our $VERSION = 'v2.3.0'; # VERSION
+our $VERSION = 'v2.4.0'; # VERSION
 # ABSTRACT: Domain Related Operations
 
 sub get_domain_by_name {
@@ -174,6 +174,10 @@ sub get_domain_name_servers_by_name {
                 croak 'Domain not found in your account';
             }
 
+            elsif( grep { $_ eq 'This domain name is expired and cannot be updated' } @{ $response->{errors} } ) {
+                return [ ];
+            }
+
             croak 'Unknown error';
         }
 
